import ts from 'typescript';
import { isDefaultImport } from '../../ast-helpers.js';
import { importVisitor as visit } from '../index.js';
export default visit(() => true, node => {
    if (ts.isImportDeclaration(node) && ts.isStringLiteralLike(node.moduleSpecifier)) {
        const specifier = node.moduleSpecifier.text;
        if (!node.importClause) {
            return { specifier, identifier: undefined, pos: node.pos };
        }
        else {
            const imports = [];
            if (isDefaultImport(node)) {
                imports.push({ specifier, identifier: 'default', pos: node.moduleSpecifier.pos });
            }
            if (node.importClause?.namedBindings) {
                if (ts.isNamespaceImport(node.importClause.namedBindings)) {
                    const symbol = node.importClause.namedBindings.symbol;
                    imports.push({ symbol, specifier, identifier: '*', pos: symbol?.declarations[0]?.pos ?? node.pos });
                }
                if (ts.isNamedImports(node.importClause.namedBindings)) {
                    node.importClause.namedBindings.elements.forEach(element => {
                        const identifier = (element.propertyName ?? element.name).getText();
                        imports.push({
                            symbol: element.symbol,
                            isTypeOnly: node.importClause?.isTypeOnly,
                            specifier,
                            identifier,
                            pos: element.pos,
                        });
                    });
                }
            }
            return imports;
        }
    }
});
